@@ -67,7 +67,7 @@ def expand_paths_vars(paths: List[str]) -> List[str]:
     return paths
 
 
-def kind_from_path(path: Path, base=False) -> str:
+def kind_from_path(path: Path, base: bool = False) -> FileType:
     """Determine the file kind based on its name.
 
     When called with base=True, it will return the base file type instead
@@ -87,7 +87,7 @@ def kind_from_path(path: Path, base=False) -> str:
                     | wcmatch.pathlib.DOTGLOB
                 ),
             ):
-                return str(k)
+                return str(k)  # type: ignore
 
     if base:
         # Unknown base file type is default
@@ -120,6 +120,7 @@ class Lintable:
         # Filename is effective file on disk, for stdin is a namedtempfile
         self.filename: str = str(name)
         self.dir: str = ""
+        self.kind: Optional[FileType] = None
 
         if isinstance(name, str):
             self.name = normpath(name)
@@ -212,10 +213,11 @@ def get_yaml_files(options: Namespace) -> Dict[str, Any]:
             git_command, stderr=subprocess.STDOUT, universal_newlines=True
         ).split("\x00")[:-1]
     except subprocess.CalledProcessError as exc:
-        _logger.warning(
-            "Failed to discover yaml files to lint using git: %s",
-            exc.output.rstrip('\n'),
-        )
+        if not (exc.returncode == 128 and 'fatal: not a git repository' in exc.output):
+            _logger.warning(
+                "Failed to discover yaml files to lint using git: %s",
+                exc.output.rstrip('\n'),
+            )
     except FileNotFoundError as exc:
         if options.verbosity:
             _logger.warning("Failed to locate command: %s", exc)
@@ -253,10 +255,19 @@ def guess_project_dir() -> str:
 
 def expand_dirs_in_lintables(lintables: Set[Lintable]) -> None:
     """Return all recognized lintables within given directory."""
-    all_files = get_yaml_files(options)
+    should_expand = False
 
-    for item in copy.copy(lintables):
+    for item in lintables:
         if item.path.is_dir():
-            for filename in all_files:
-                if filename.startswith(str(item.path)):
-                    lintables.add(Lintable(filename))
+            should_expand = True
+            break
+
+    if should_expand:
+        # this relies on git and we do not want to call unless needed
+        all_files = get_yaml_files(options)
+
+        for item in copy.copy(lintables):
+            if item.path.is_dir():
+                for filename in all_files:
+                    if filename.startswith(str(item.path)):
+                        lintables.add(Lintable(filename))
